<?php

namespace Drupal\acquia_perz\EventSubscriber;

use Drupal\acquia_perz\ClientFactory;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Response subscriber to handle Graphql responses.
 */
class ResponseSubscriber implements EventSubscriberInterface {

  /**
   * The Acauia Perz Entity Helper service.
   *
   * @var \Drupal\acquia_perz\ClientFactory
   */
  protected $clientFactory;

  /**
   * Constructs a ResponseSubscriber object.
   *
   * @param \Drupal\acquia_perz\ClientFactory $client_factory
   *   The Acauia Perz Client Factpry service.
   */
  public function __construct(ClientFactory $client_factory) {
    $this->clientFactory = $client_factory;
  }

  /**
   * Processes attachments for Graphql responses.
   *
   * @param \Symfony\Component\HttpKernel\Event\ResponseEvent $event
   *   The event to process.
   */
  public function onRespond(ResponseEvent $event) {
    $request = $event->getRequest();
    $response = $event->getResponse();
    if ($request->getPathInfo() === '/perz3') {

      $referer = $request->headers->get('referer');
      $host = $request->getSchemeAndHttpHost();
      if ($referer === $host . '/admin/config/graphql/servers/manage/perz/explorer') {
        return $response;
      }
      $key = $this->clientFactory->authenticate($request);
      if ($key) {
        $signed_response = $this->clientFactory->generateResponseWithSignature($request, $response, $key);
        $event->setResponse($signed_response);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::RESPONSE][] = ['onRespond'];
    return $events;
  }

}
